# Präsentation meines neuen Copilot für SEO Analysen 🚀

> **Source:** [Antonio Blago](https://www.youtube.com/channel/UCoIBDdswc5VViHYPTKd0HwA) | **Duration:** 07:34 | **Published:** 20251209
> **URL:** [https://www.youtube.com/watch?v=ikqfIqFv2Fc](https://www.youtube.com/watch?v=ikqfIqFv2Fc)
> **Views:** 27
> **Tags:** SEOcopilot, EEATAnalyse, SEOAutomatisierung, SEOProjektTracking, KeywordTools, SEOOptimierung, ContentStrategie, BacklinkStrategie, AISEO, SEOAnalytics

Willkommen zur Premiere meines SEO Copilot Tools, meinem eigenen KI-gestützten SEO Assistenten auf antonioblago.com.
In diesem Video zeige ich dir Schritt für Schritt, wie du mit der kostenlosen Version startest, ein Projekt anlegst und deinen gesamten E E A T Score analysieren kannst.

Hier Account...

---

## Table of Contents

- [Einführung und Tool Premiere](#einfhrung-und-tool-premiere-00:00-00:32)
- [Kostenlos registrieren und Projekt anlegen](#kostenlos-registrieren-und-projekt-anlegen-00:32-01:04)
- [E E A T Tracking und Konkurrenzvergleich](#e-e-a-t-tracking-und-konkurrenzvergleich-01:04-01:36)
- [Technische Basis, Experience, Expertise im Überblick](#technische-basis-experience-expertise-im-berblick-01:36-01:57)
- [Authority, Trust und Onlinepräsenz verstehen](#authority-trust-und-onlineprsenz-verstehen-01:57-02:23)
- [Wöchentliche Analysen und Score Verlauf](#wchentliche-analysen-und-score-verlauf-02:23-03:12)
- [Projekt Einstellungen, Rollen, Zielgruppen](#projekt-einstellungen-rollen-zielgruppen-03:12-03:56)
- [Score Warnungen und Benachrichtigungen](#score-warnungen-und-benachrichtigungen-03:56-04:20)
- [KI Dialoge, Empfehlungen und Verlauf](#ki-dialoge-empfehlungen-und-verlauf-04:20-04:48)
- [Credits, Abos und Quick Actions](#credits-abos-und-quick-actions-04:48-05:28)
- [Keyword Extraction und Bloggenerator](#keyword-extraction-und-bloggenerator-05:28-06:10)
- [Keyword Speicherung und Produktfeedback](#keyword-speicherung-und-produktfeedback-06:10-06:53)
- [Hinweise, Kontakt und Schlusswort](#hinweise-kontakt-und-schlusswort-06:53-07:34)

---

### Einführung und Tool Premiere (00:00 - 00:32)

Herzlich willkommen äh zu der Premiere von meinem SEO Tool. In dem Sinne ähm mein eigenes programmiertes SEO Tool auf meiner Domain antonioblago.com. Ähm und hier habe ich ein Testccount, also die freie Version. Ähm, da könnt ihr euch einfach registrieren unter antonioblago.com äh Register und ähm da solltet ihr euch einfach anmelden können und dann kriegt ihr

---

### Kostenlos registrieren und Projekt anlegen (00:32 - 01:04)

und ähm da solltet ihr euch einfach anmelden können und dann kriegt ihr einen Link äh E-Mail confirmation und dann habt ihr da ein gratis Account und könnt auch in dem Sinne ähm äh ein SEOjekt anlegen. Also hier habe ich quasi ein SEOjekt ähm angelegt. Ähm könnt ihr quasi euer EAT äh tracken von euren äh eigener Webseite und von euren Mitbewerbern. Da könnt ihr

---

### E E A T Tracking und Konkurrenzvergleich (01:04 - 01:36)

euren äh eigener Webseite und von euren Mitbewerbern. Da könnt ihr in der kostenfreien Version ein Projekt anlegen und bis zu fünf Konkurrenten anlegen. Die könnt ihr dann ähm dort auch hier noch mal tracken und seht äh quasi die Analyse Hinsicht äh Ansicht. Ähm habt ihr so ein Scoreverlauf. Ähm, genau. Und dann hier noch mal diese äh Indikatoren, also technisch, Präsenz, Trust, äh Authority, Expertise, ähm Experience.

---

### Technische Basis, Experience, Expertise im Überblick (01:36 - 01:57)

Trust, äh Authority, Expertise, ähm Experience. Und im Detail könnt ihr euch dann auch immer die Details noch mal anschauen äh von euren äh eigenen Webseite oder von euren Konkurrenten, wie die so aufgestellt ist. Ähm, genau. technische Basis in dem Sinne alles, was rund um äh Server Impressum so angeht, dann Experience

---

### Authority, Trust und Onlinepräsenz verstehen (01:57 - 02:23)

Sinne alles, was rund um äh Server Impressum so angeht, dann Experience auch sehr wichtig, persönliche Erfahrung äh reinzubringen, Fachkompetenz, Content ähm dann Autorität, Branchenanerkennung äh Bewertung, genau Trustiness ist auch Vertrauen, Transparenz und dann die Online Präsenz auch noch mal Social Media äh in dem Sinne auch organisches Sichtbarkeit. Ähm, genau. Und dann seht ihr auch noch mal

---

### Wöchentliche Analysen und Score Verlauf (02:23 - 03:12)

Ähm, genau. Und dann seht ihr auch noch mal hier die Übersicht äh aller Analysen. Also, könnt ihr euch an einstellen, dass ihr quasi wöchentlich ähm das äh einmal analysiert und dann tracken lassen und äh dann bekommt ihr so eine Übersicht, was man machen müsste. Ähm, dann noch mal was erfindet. Hier z.B. die Zitate und Quellenangaben. Ähm, genau. Und dann zusätzlich habt ihr dann noch den äh SEO Copilot ähm wo auch dann noch mal äh ein Projekt verbinden könnt oder auch anlegen könnt. Ähm und da könnt ihr auch äh in den Projekten verwalten. ähm könnt ihr euch auch noch mal ähm

---

### Projekt Einstellungen, Rollen, Zielgruppen (03:12 - 03:56)

auch äh in den Projekten verwalten. ähm könnt ihr euch auch noch mal ähm dann in den Einstellungen auch ganz wichtig ähm äh quasi auch noch mal hier die Einstellung wöchentlich jeden Montag z.B. dass die Analyse durchläuft und dann auch äh was ist euer Projekttyp? äh dann Zielgruppe, deine Rolle im Unternehmen, deine Contentprache und dann seissen. Ähm, genau. Dann bekommst du eine E-Mail Benachrichtigung und auch äh wenn dein Score zu arg ähm abweicht, dann kriegst du auch noch mal eine äh Score äh Warnung in dem Sinne, Schwellenwertwarnung. Ähm,

---

### Score Warnungen und Benachrichtigungen (03:56 - 04:20)

Schwellenwertwarnung. Ähm, genau. Das ist super, wenn ihr da alles ausfüllt, ähm, dass die KI da auch immer die ganzen Daten hat. Ähm, und genau, dann könnt ihr z.B. hier auch ähm dann auch fragen, z.B. helf mir mein Eat zu verbessern und dann zieht er sich das Projekt ähm eure Daten dazu und dann hältst du dazu auch Anweisung. Ähm,

---

### KI Dialoge, Empfehlungen und Verlauf (04:20 - 04:48)

Projekt ähm eure Daten dazu und dann hältst du dazu auch Anweisung. Ähm, alles wird quasi gespeichert ähm unter Verlauf. Kannst du auch neue Unterhaltungen machen, wie bei Chat GBT. Ähm, und dann kriegst du auch immer so Empfehlungen. Äh, z.B. hier Medical Link Building und ähm dann bei jeder Ausführung äh kostet es halt Credits. Ähm und die kannst du auch aufladen separat. ähm oder du kannst ein Abonnement

---

### Credits, Abos und Quick Actions (04:48 - 05:28)

auch aufladen separat. ähm oder du kannst ein Abonnement abschließen. Ähm genau. Ansonsten kannst du hier auch alle möglichen Quick Actions durchführen, ähm wie Blockschreiben, äh Keywordempfehlung und äh du kannst hier auch quasi dann deine Keywords aus dem Prom ziehen. ähm muss nicht ähm alles so rauskopiert werden äh wie bei Chat GBT, sondern ich habe das so äh erstellt, dass man jetzt äh in dem Sinne auch gleich äh die Keywords einfach äh per Button rauskopieren kann und sie in deinem SEO Tool oder noch mal äh in ChatBT noch mal

---

### Keyword Extraction und Bloggenerator (05:28 - 06:10)

rauskopieren kann und sie in deinem SEO Tool oder noch mal äh in ChatBT noch mal reinzupasten. Ähm genau, der erstellt jetzt hier z.B. eine ganze Outreach äh Agenda, wie man jetzt z.B. Backlinks aufbauen kann im medizinischen Bereich. Ähm, genau. Die die Strategie äh kannst du dann übernehmen und äh dann auch selber durchführen. Ähm, genau. Dann kannst du auch hier z.B. Keywords speichern drücken auch was ganz immer ganz hilfreich ist, wenn du es gut findest, auch hier hilfreich zu klicken. Ähm und ähm dann werden dann

---

### Keyword Speicherung und Produktfeedback (06:10 - 06:53)

es gut findest, auch hier hilfreich zu klicken. Ähm und ähm dann werden dann halt auch äh Feedback zur Produktweiterentwicklung auch empfohlen, ne? Also z.B. jetzt hier z.B. die Keywords gespeichert, auch kategorisiert nach Longtail Fragen ähm Hauptteil und dann kannst du auch noch mal hier die Keywords kopieren oder äh für Chat GBT auch noch mal nutzen. Ähm genau mit quasi prompt. Ähm, genau. Und dann äh schreibt er hier dir einen Blogartikel mit diesem vorgefertigten Prompt. Genau. Ansonsten, wenn du Fragen hast,

---

### Hinweise, Kontakt und Schlusswort (06:53 - 07:34)

mit diesem vorgefertigten Prompt. Genau. Ansonsten, wenn du Fragen hast, äh immer gerne hier an diese E-Mail richten oder über LinkedIn. Ähm, genau. Gibt bitte keine sensiblen oder Personen bezogenen Daten ein. Äh und ähm die KI ist auch nicht ganz fehlerfrei. Insofern ähm prüfe immer vorher, wenn du irgendwas tust, ähm ob das auch alles plausibel ist. Ähm genau. Und frage mich bitte eher, bevor du ähm nicht weißt, ob das wirklich was hilft. Genau. Und dann wünsche ich dir viel Erfolg und ähm freue mich auf dein Feedback und ja, viel Spaß.

---


*Transcript source: youtube_auto_generated*
*Confidence: 80%*